<?php
/* 
 Opus Fashion Blog Functions File 
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit; 

//Required Plugins Init
require_once( get_template_directory() . '/admin/tgm/init.php' );

/*
 Theme Setup Functions to setup
 support for WordPress core  functionality.
 */
function opus_theme_setup() {
	//load text domain for translation
	load_theme_textdomain( 'opusfashion' );
	
	//theme support for feed
	add_theme_support( 'automatic-feed-links' );
	
	//theme support for title tag
	add_theme_support( 'title-tag' );
	
	//theme support for post thumbnails
	add_theme_support( 'post-thumbnails' );
	
	//setting up content width
	if ( ! isset( $content_width ) ) {
		$content_width = 900;
	}
	
	//registring menus for the theme
	register_nav_menus( array(
		'main'    => __( 'Main Menu', 'opusfashion' ),
	) );
	
	//theme support for components
	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );
	
	//theme support for post formats
	add_theme_support( 'post-formats', array(
		'image',
		'video',
		'gallery',
		'audio',
		'quote',
		'link',
	) );
}
add_action( 'after_setup_theme', 'opus_theme_setup' );

/*
   enqueue all javascript and css files that are 
   used for the theme.
 */
function opus_enqueue_styles_scripts(){
		wp_enqueue_style( 'opus-bootstrap', get_template_directory_uri() . '/libraries/bootstrap/css/bootstrap.min.css', array(), '3.3.7' );
		wp_enqueue_style( 'opus-owl-carousel', get_template_directory_uri() . '/libraries/owl-carousel/css/owl.carousel.min.css', array(), '1.0.0' );
		wp_enqueue_style( 'opus-owl-theme', get_template_directory_uri() . '/libraries/owl-carousel/css/owl.theme.default.min.css', array(), '1.0.0' );
		wp_enqueue_style( 'opus-animate-it', get_template_directory_uri() . '/libraries/animate-css/animate.css', array(), '1.0.0' );
		wp_enqueue_style( 'opus-font-awesome', get_template_directory_uri() . '/libraries/font-awesome/css/font-awesome.min.css', array(), '4.7.0' );
		wp_enqueue_style( 'opus-fashion', get_stylesheet_uri(), array('opus-bootstrap'), '3.3.7' );
		wp_enqueue_style( 'opus-custom-styles', get_template_directory_uri() . '/css/style.css', array(), '1.0.5' );
		wp_enqueue_style( 'opus-dynamic-styles', get_template_directory_uri() . '/css/opus-dynamic.css', array(), '1.0.0' );
	 	if ( is_singular() ) {
			wp_enqueue_script( "comment-reply" );
		}
		wp_enqueue_script( "opus-boostrap-js", get_template_directory_uri() . '/libraries/bootstrap/js/bootstrap.min.js' , array("jquery"), false, true );
		wp_enqueue_script( "opus-owl-carousel-js", get_template_directory_uri() . '/libraries/owl-carousel/js/owl.carousel.js' , array("opus-boostrap-js"), false, true );
		wp_enqueue_script( "opus-custom-js", get_template_directory_uri() . '/js/main.js' , array("opus-owl-carousel-js"), false, true );
}
add_action( 'wp_enqueue_scripts', 'opus_enqueue_styles_scripts' );

/**
 * Register widget area.
 */
function opus_widgets() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'opusfashion' ),
		'id'            => 'opus-blog-sidebar',
		'description'   => __( 'Displays Widgets on Blog Page.', 'opusfashion' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title main-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 1', 'opusfashion' ),
		'id'            => 'opus-footer-widget-1',
		'description'   => __( 'Displays Widgets in Footer Section 1.', 'opusfashion' ),
		'before_widget' => '<aside id="%1$s" class="widget footer-widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title footer-widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 2', 'opusfashion' ),
		'id'            => 'opus-footer-widget-2',
		'description'   => __( 'Displays Widgets in Footer Section 2 (If Enabled from Theme Options).', 'opusfashion' ),
		'before_widget' => '<aside id="%1$s" class="widget footer-widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title footer-widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 3', 'opusfashion' ),
		'id'            => 'opus-footer-widget-3',
		'description'   => __( 'Displays Widgets in Footer Section 3 (If Enabled from Theme Options).', 'opusfashion' ),
		'before_widget' => '<aside id="%1$s" class="widget footer-widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title footer-widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 4', 'opusfashion' ),
		'id'            => 'opus-footer-widget-4',
		'description'   => __( 'Displays Widgets in Footer Section 4 (If Enabled from Theme Options).', 'opusfashion' ),
		'before_widget' => '<aside id="%1$s" class="widget footer-widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h4 class="widget-title footer-widget-title">',
		'after_title'   => '</h4>',
	) );
}
add_action( 'widgets_init', 'opus_widgets' );

require get_template_directory() . '/misc/post-types.php';
require get_template_directory() . '/misc/custom-fields.php';
require get_template_directory() . '/misc/misc.php';
require get_template_directory() . '/widgets/init.php';
require get_template_directory() . '/misc/compile-css.php';