<?php 
/*
 * This file contains all the misc functions
 * which involves complex logic. Ideally done
 * for code clarity
 *
 * ver: 1.0.0
 */

// get theme options variable available to be used throughout the template
function opus_get_options(){
	global $opus_options;
	return $opus_options;
}

// get header social links status and links
function opus_get_social_links(){
	$theme_options = opus_get_options();
	$social_status = $theme_options['opus-social-status'];
	if ($social_status == 1){
		$facebook_link = $theme_options['opus-facebook'];
		$linkedin_link = $theme_options['opus-linkedin'];
		$twitter_link = $theme_options['opus-twitter'];
		$vimeo_link = $theme_options['opus-vimeo'];
		$google_link = $theme_options['opus-google-plus'];
		$html = "<div class='col-xs-6 social-buttons'>";
        $html .= "<ul class='text-right'>";
		if (!empty($facebook_link)){
              $html .= "<li><a href='" . esc_url($facebook_link) . "' target='_blank'><i class='fa fa-facebook-square' aria-hidden='true'></i></a></li>";
		}
		if (!empty($linkedin_link)){
              $html .= "<li><a href='" . esc_url($linkedin_link) . "' target='_blank'><i class='fa fa-linkedin-square' aria-hidden='true'></i></a></li>";
		}
		if (!empty($twitter_link)){
              $html .= "<li><a href='" . esc_url($twitter_link) . "' target='_blank'><i class='fa fa-twitter-square' aria-hidden='true'></i></a></li>";
		}
		if (!empty($vimeo_link)){
              $html .= "<li><a href='" . esc_url($vimeo_link) . "' target='_blank'><i class='fa fa-vimeo-square' aria-hidden='true'></i></a></li>";
		}
		if (!empty($google_link)){
              $html .= "<li><a href='" . esc_url($google_link) . "' target='_blank'><i class='fa fa-google-plus-square' aria-hidden='true'></i></a></li>";
		}
        $html .= "</ul>";
        $html .= "</div>";
		return $html;
	}	
	return false;
}

// get blog listing layout settings from theme options
function opus_get_blog_listing_layout(){
	$theme_options = opus_get_options();
	$blog_listing_layout = esc_attr($theme_options['opus-blog-listing-layout']);
	return $blog_listing_layout;
}

// get setup post/pages content area classes
function opus_layout_class($type){
	$theme_options = opus_get_options();
	$page_layout = esc_attr($theme_options['opus-' . $type . '-layout']);
	if($page_layout == "full-width"){
		echo "col-md-12";
	} else {
		echo "col-md-8";
	}	
}

//filter for customization of excerpt ending text
function opus_excerpt_more( $more ) {
	return ' ...';
}
add_filter( 'excerpt_more', 'opus_excerpt_more' );

function opus_excerpt_length( $length ) {
	return 20;
}
add_filter( 'excerpt_length', 'opus_excerpt_length', 999 );

// Enable shortcodes in text widgets
add_filter('widget_text','do_shortcode');

//add classes to the post according to the layout selected from theme options of selected template for the page
function opus_layout_post_class( $classes ) {
	$blog_listing_layout = opus_get_blog_listing_layout();
	if (($blog_listing_layout == "list" && !is_page_template( array ("template-grid-layout.php") )) || is_single() || is_page_template( array ("template-list-layout.php") )){
		$classes[] = "blog-post col-lg-12";		
	} else {
		$classes[] = "grid-post col-md-6";
	}
	return $classes;
}
add_filter( 'post_class', 'opus_layout_post_class');

// get setup post/pages content area layout for sidebar status checkup
function opus_layout($type){
	$theme_options = opus_get_options();
	$page_layout = esc_attr($theme_options['opus-' . $type . '-layout']);
	return $page_layout;
}

// custom pagination for the template used to display blog posts
function opus_pagination($numpages = '', $pagerange = '', $paged='') {
  if (empty($pagerange)) {
    $pagerange = 2;
  }
  global $paged;
  if (empty($paged)) {
    $paged = 1;
  }
  if ($numpages == '') {
    global $wp_query;
    $numpages = $wp_query->max_num_pages;
    if(!$numpages) {
        $numpages = 1;
    }
  }
  $pagination_args = array(
    'base'            => get_pagenum_link(1) . '%_%',
    'format'          => 'page/%#%',
    'total'           => $numpages,
    'current'         => $paged,
    'show_all'        => False,
    'end_size'        => 1,
    'mid_size'        => $pagerange,
    'prev_next'       => True,
    'prev_text'       => __('Previous', 'opusfashion'),
    'next_text'       => __('Next', 'opusfashion'),
    'type'            => 'plain',
    'add_args'        => false,
    'add_fragment'    => ''
  );
  $paginate_links = paginate_links($pagination_args);
  if ($paginate_links) {
    echo "<nav class='custom-pagination pagination'>";
	  	echo '<div class="nav-links">';
	  		echo $paginate_links;
    	echo "</div>";
    echo "</nav>";
  }
}

// get gallery images id from Gallery post format
if(!function_exists('get_gallery_attachments')) {
	function get_gallery_attachments(){
		global $post;
		$post_content = $post->post_content;
		preg_match('/\[gallery.*ids=.(.*).\]/', $post_content, $ids);
		if (!empty($ids)) {
			$images_id = explode(",", $ids[1]);
			return $images_id;
		}
	}
}

function opus_top_header(){
	$theme_options = opus_get_options();
	$topbar_status = $theme_options['opus-topbar-status'];
	$phone = $theme_options['opus-phone'];
	$email = $theme_options['opus-email'];
	$facebook = $theme_options['opus-facebook'];
	$twitter = $theme_options['opus-twitter'];
	$linkedin = $theme_options['opus-linkedin'];
	$youtube = $theme_options['opus-youtube'];

	if ($topbar_status) {
		$html = '<div class="top-header">';
		$html .= '<div class="container">';
		$html .= '<div class="row">';
		$html .= '<div class="col-sm-6">';
		$html .= '<ul class="contact-links">';
		if ($phone){
			$html .= '<li class="tel"><a href="tel:' . $phone .'">' . $phone . '</a></li>';
		}
		if ($email){
			$html .= '<li class="email"><a href="mailto:' . $email . '">' . $email . '</a></li>';
		}
		$html .= '</ul>';
   		$html .= '</div>';
   		$html .= '<div class="col-sm-6">';
		$html .= '<ul class="social-icons">';
		if($facebook){
			$html .= '<li class="fb"><a href="' . esc_url($facebook) . '" target="_blank"><i class="fa fa-facebook"></i></a></li>';
		}
		if($twitter){
			$html .= '<li class="tw"><a href="' . esc_url($twitter) . '" target="_blank"><i class="fa fa-twitter"></i></a></li>';
		}
		if($linkedin){
			$html .= '<li class="linkedin"><a href="' . esc_url($linkedin) . '" target="_blank"><i class="fa fa-linkedin"></i></a></li>';
		}
		if($youtube){
			$html .= '<li class="youtube"><a href="' . esc_url($youtube) . '" target="_blank"><i class="fa fa-youtube"></i></a></li>';
		}
		$html .= '</ul>';
		$html .= '</div>';
  		$html .= '</div>';
   		$html .= '</div>';
   		$html .= '</div>';	
	}
	
	return $html;
}

function opus_primary_menu_fallback(){
    echo '<div class="menu-main-menu-container"><ul class="menu"><li><a href="'.admin_url( 'nav-menus.php' ).'">Click to assign Menu</a></li></ul></div>';
}


function opus_banner(){
	$theme_options = opus_get_options();
	$slider_status = $theme_options['opus-slider-status'];
	
	if ($slider_status){
		$args = array(
			'post_type' => 'opus_slider',
			'posts_per_page' => -1,
		);

		$html = "";
		$slider_query = new WP_Query( $args );
		if ( $slider_query->have_posts() ) {
			$html .= '<div class="main-slider owl-carousel">';
				while ( $slider_query->have_posts() ) {
				$slider_query->the_post();
					$html .= '<div class="slide-item">';
						if (get_field("link_status", $slider_query->ID) == 'enabled'){
							if (get_field("link_type", $slider_query->ID) == 'post'){
								$href = get_field("page_link", $slider_query->ID);
							} else {
								$href = get_field("external_link", $slider_query->ID);							
							}
							$html .= '<a href="' . esc_url($href) . '">';
						}
						$html .= '<img src="' . esc_url(get_field("image", $slider_query->ID)) . '" class="img-responsive" />';
						$html .= '<div class="caption">';
						$html .= get_field("caption", $slider_query->ID);
						$html .= '</div>';
						if (get_field("link_status", $slider_query->ID) == 'enabled'){
							$html .= '</a>';					
						}
					$html .= '</div>';
				 }
			$html .= '</div>';
			/* Restore original Post Data */
			wp_reset_postdata();
		}	

		return $html;
	}
}


function opus_search_form($html) {
	$html = str_replace('id="s"', 'id="s" placeholder="Enter Keyword"', $html);
	return $html;
}
add_filter('get_search_form', 'opus_search_form');

// get footer widgets layout
function opus_get_footer_layout($column){
	$theme_options = opus_get_options();
	$footer_class = esc_attr($theme_options['opus-footer-widget-' . $column . '-columns']);
	echo $footer_class;
}

// get footer copyrights status and text
function opus_get_copyrights_credit(){
	$theme_options = opus_get_options();
	$copyrights_status = $theme_options['opus-copyrights-status'];
	if ($copyrights_status == 1){
		$copyrights_text = $theme_options['opus-copyrights-text'];
		$html = "<div class='copyright'>";
        $html .= "<div class='text-center'>";
        $html .= esc_html($copyrights_text);
        $html .= "</div>";
        $html .= "</div>";
		return $html;
	}	
	return false;
}