<?php
/**
 * The Opus About Widget.
 *
 */
class Opus_About_Widget extends WP_Widget {
	
	public function __construct() {
		/* Widget options. */
		$widget_options = array(
			'classname'   => 'opus-about-widget',
			'description' => __( 'About Widget', 'opusfashion'),
			'customize_selective_refresh' => true
		);
		/* Create the widget. */
		parent::__construct(
			'opus_about_widget',                                                 					
			__( 'Opus About Widget', 'opusfashion' ), 		
			$widget_options
		);
	}
	
	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 */
	public function widget( $args, $instance ) {
		extract( $args );
		$title = $instance[ 'title' ] ? $instance['title'] : __("About Me", "opusfashion");
		$image_url = $instance[ 'image-url' ] ? esc_url($instance[ 'image-url' ]) : "";
		$about_text = $instance[ 'about-text' ] ? $instance[ 'about-text' ] : "";
		$facebook = $instance[ 'facebook' ] ? esc_url($instance[ 'facebook' ]) : "";
		$twitter = $instance[ 'twitter' ] ? esc_url($instance[ 'twitter' ]) : "";
		$linkedin = $instance[ 'linkedin' ] ? esc_url($instance[ 'linkedin' ]) : "";
		$youtube = $instance[ 'youtube' ] ? esc_url($instance[ 'youtube' ]) : "";
		// Output the theme's $before_widget wrapper.
		echo $before_widget;
		echo $before_title . $title . $after_title;		
		if ($image_url != ""){
			echo '<div class="about-images">';
			echo '<img src="' . $image_url . '" alt="about me" />';
			echo '</div>';
		}
		if ($about_text != ""){
			echo "<p>" . $about_text . "</p>";
		}
		echo '<ul class="social-icons">';	
		if ($facebook != ""){
			echo '<li class="fb"><a href="' . $facebook . '" target="_blank"><i class="fa fa-facebook"></i></a></li>';
		}
		if ($twitter != ""){
			echo '<li class="tw"><a href="'. $twitter .'" target="_blank"><i class="fa fa-twitter"></i></a></li>';
		}
		if ($linkedin != ""){
			echo '<li class="linkedin"><a href="'. $linkedin .'" target="_blank"><i class="fa fa-linkedin"></i></a></li>';
		}
		if ($youtube != ""){
			echo '<li class="youtube"><a href="' . $youtube . '" target="_blank"><i class="fa fa-youtube"></i></a></li>';
		}
		echo '</ul>';
		// Close the theme's widget wrapper.
		echo $after_widget;
	}	 
	
	/**
	 * Updates the widget control options for the particular instance of the widget.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance[ 'title' ] = strip_tags( $new_instance[ 'title' ] );
		$instance[ 'image-url' ] = strip_tags( $new_instance[ 'image-url' ] );
		$instance[ 'about-text' ] = strip_tags( $new_instance[ 'about-text' ] );
		$instance[ 'facebook' ] = strip_tags( $new_instance[ 'facebook' ] );
		$instance[ 'twitter' ] = strip_tags( $new_instance[ 'twitter' ] );
		$instance[ 'linkedin' ] = strip_tags( $new_instance[ 'linkedin' ] );
		$instance[ 'youtube' ] = strip_tags( $new_instance[ 'youtube' ] );
		return $instance;
	}
	
	/**
	 * Displays the widget control options in the Widgets admin screen.
	 */
	public function form( $instance ) {
		 $title = ! empty( $instance['title'] ) ? $instance['title'] : ''; 
		 $image_url = ! empty( $instance['image-url'] ) ? $instance['image-url'] : ''; 
		 $about_text = ! empty( $instance['about-text'] ) ? $instance['about-text'] : '';
		 $facebook = ! empty( $instance['facebook'] ) ? $instance['facebook'] : ''; 
		 $twitter = ! empty( $instance['twitter'] ) ? $instance['twitter'] : ''; 
		 $linkedin = ! empty( $instance['linkedin'] ) ? $instance['linkedin'] : ''; 
		 $youtube = ! empty( $instance['youtube'] ) ? $instance['youtube'] : ''; 
?>
		  <p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>">Title:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $title ); ?>" class="widefat" />
		  </p>
  		  <p>
			<label for="<?php echo $this->get_field_id( 'image-url' ); ?>">Image URL:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'image-url' ); ?>" name="<?php echo $this->get_field_name( 'image-url' ); ?>" value="<?php echo esc_url( $image_url ); ?>" class="widefat" />
		  </p>
  		  <p>
			<label for="<?php echo $this->get_field_id( 'about-text' ); ?>">Short Bio:</label>
			<textarea class="widefat" id="<?php echo $this->get_field_id( 'about-text' ); ?>" rows="8" name="<?php echo $this->get_field_name( 'about-text' ); ?>"><?php echo esc_attr( $about_text ); ?></textarea>
		  </p>
  		  <p>
			<label for="<?php echo $this->get_field_id( 'facebook' ); ?>">Facebook:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'facebook' ); ?>" name="<?php echo $this->get_field_name( 'facebook' ); ?>" value="<?php echo esc_url( $facebook ); ?>" class="widefat" />
		  </p>
  		  <p>
			<label for="<?php echo $this->get_field_id( 'twitter' ); ?>">Twitter:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'twitter' ); ?>" name="<?php echo $this->get_field_name( 'twitter' ); ?>" value="<?php echo esc_url( $twitter ); ?>" class="widefat" />
		  </p>
  		  <p>
			<label for="<?php echo $this->get_field_id( 'linkedin' ); ?>">Linked In:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'linkedin' ); ?>" name="<?php echo $this->get_field_name( 'linkedin' ); ?>" value="<?php echo esc_url( $linkedin ); ?>" class="widefat" />
		  </p>
  		  <p>
			<label for="<?php echo $this->get_field_id( 'youtube' ); ?>">Youtube:</label>
			<input type="text" id="<?php echo $this->get_field_id( 'youtube' ); ?>" name="<?php echo $this->get_field_name( 'youtube' ); ?>" value="<?php echo esc_url( $youtube ); ?>" class="widefat" />
		  </p>
		  <?php 
	}
}

function opus_about_widget() { 
  	register_widget( 'Opus_About_Widget' );
}
add_action( 'widgets_init', 'opus_about_widget' );